\name{ais}
\alias{AIS}
\alias{ais}
\title{Australian athletes data}
\non_function{}
\description{
Data on 102 male and 100 female athletes collected at the Australian
Institute of Sport, courtesy of Richard Telford and Ross Cunningham.
}
\format{This data frame contains the following columns:
 \describe{
    \item{Sex}{
 (0 = male or 1 = female)
    }
    \item{Ht}{
 height (cm)
    }
    \item{Wt}{
 weight (kg)
    }
    \item{LBM}{
 lean body mass
    }
    \item{RCC}{
 red cell count
    }
    \item{WCC}{
 white cell count
    }
    \item{Hc}{
 Hematocrit
    }
    \item{Hg}{
 Hemoglobin
    }
 }
}
\details{}
\source{R. D. Cook and S. Weisberg (1999). \emph{Applied
Statistics Including Computing and Graphics}.  New York:  Wiley.}
\keyword{datasets}

\eof
\name{cosangle}
\alias{cosangle}
\alias{cosangle1}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Compute the cosine of the angle between a vector and a subspace }
\description{
\code{cosangle1} returns the cosine of the
angle between a vector vecs  and the subspace spanned
by the columns of the matrix mat.  For cosangle, vecs can be a matrix, in
which case cosangle1 is called for each column in vecs.
}
\usage{
cosangle(mat, vecs)
cosangle1(mat, vec)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{mat}{ A matrix the provides the basis for a subspace}
  \item{vecs}{ A vector with the same number of rows as mat, or a matrix
  with the same number of rows as mat}
  \item{vec}{ A vector with the same number of rows as mat}
}
\details{
  \code{cosangle1} computes the cosine of the angle between vec and the orthogonal projection
  of vec onto the column space of mat.  \code{cosangle} repeats this computation
  for each column of vecs.
}
\value{
  cosangle1 returns a single value and cosangle returns a vector.
}
\author{Sanford Weisberg <sandy@stat.umn.edu> }
\keyword{regression}

\eof
\name{dr-internal}
\alias{dr.fit.M}
\alias{dr.fit.M.mphd}
\alias{dr.fit.M.mphdres}
\alias{dr.fit.M.mqphd}
\alias{dr.fit.M.msir}
\alias{dr.fit.M.phd}
\alias{dr.fit.M.phdq}
\alias{dr.fit.M.phdres}
\alias{dr.fit.M.phdy}
\alias{dr.fit.M.save}
\alias{dr.fit.M.sir}
\alias{dr.fit.y.default}
\alias{dr.fit.y.phd}
\alias{dr.fit.y.phdq}
\alias{dr.fit.y.phdres}
\alias{dr.fit.y.phdy}
\alias{dr.x.omitted}
\alias{dr.y.name}
\alias{make.Mhat.phdq}
\alias{mat.normalize}
\alias{permute}
\alias{whichengine}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Internal dr functions }
\description{
  ~~ A concise (1-5 lines) description of what the function does. ~~
}
\usage{
dr.fit.M(object, ...)
dr.fit.y(object )
dr.x.omitted(z)
dr.y.name(object)
make.Mhat.phdq(pars)
mat.normalize(a)
permute(n)
}
\details{
  These are not to be called by the user.
}
}
\author{ Sanford Weisberg <sandy@stat.umn.edu>}

\keyword{ internal }

\eof
\name{dr}
\alias{dr}
\alias{plot.dr}
\alias{print.dr}
\alias{summary.dr}
\alias{print.summary.dr}
\alias{model.matrix.dr}
\alias{dr.weights}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Dimension reduction regression}
\description{
 The function dr implements dimension reduction methods, including SIR, SAVE and pHd.
}
\usage{
dr(formula, data=list(), subset, weights, na.action=na.omit, method="sir", 
     contrasts=NULL,offset=NULL, ...)
dr.weights(formula, data=list(), subset, weights, na.action=na.omit, method="sir", 
     contrasts=NULL,offset=NULL, ...)
 }

\arguments{
 \item{formula}{a symbolic description of the model to be fit. The details of
          the model are the same as for lm. }
 \item{data}{ an optional data frame containing the variables in the model.
           By default the variables are taken from the environment from
           which `dr' is called.}
 \item{subset}{an optional vector specifying a subset of observations to be
          used in the fitting process.}
 \item{weights}{an optional vector of weights to be used where appropriate.}
 \item{na.action}{a function which indicates what should happen when the data
          contain `NA's.  The default is `na.omit,' which will force
          calculations on a complete subset of cases.}
 \item{method}{This character string specifies the method of fitting.  ``sir"
          specifies sliced inverse regression and ``save" specifies sliced
          average variance estimation.  ``phdy" uses principal hessian
          directions using the response as suggested by Li, and ``phdres" 
          uses the LS residuals as suggested by Cook. Other methods may be
          added}
 \item{contrasts}{an optional list. See the `contrasts.arg' of
          `model.matrix.default'.}
 \item{offset}{Set an offset or NULL}
 \item{\dots}{additional items that may be required or permitted by some 
          methods.
          \code{nslices} is the number of slices used by sir and save.
	  \code{numdir} is the maximum number of directions to compute, with
	  default equal to 4.}
}

\details{
The general regression problem studies \eqn{F(y|x)}, the conditional
distribution of a response \eqn{y} given a set of predictors \eqn{x}.  
This function provides methods for estimating the dimension and central
subspace of a general regression problem.  That is, we want to find a 
\eqn{p \times d}{p by d} matrix \eqn{B} such that 
\deqn{F(y|x)=F(y|B'x)}  
Both the dimension \eqn{d} and the subspace
\eqn{R(B)} are unknown.  These methods make few assumptions.  All the methods
available in this function estimate the unknowns by study of the inverse
problem, \eqn{F(x|y)}.  In each, a kernel matrix \eqn{M} is estimated such
that the column space of \eqn{M} should be close to the central subspace.
Eigenanalysis of \eqn{M} is then used to estimate the central subspace.
Objects created using this function have appropriate print, summary and plot
methods.

Weights can be used, essentially to specify the relative 
frequency of each case in the data.  Empirical weights that make 
the contours of the weighted sample closer to elliptical can be 
computed using \code{\link{dr.weights}}.  
This will usually result in zero weight for some 
cases.  The function will set zero estimated weights to missing.

Several functions are provided that require a dr object as input.  
\code{dr.permutation.tests} uses a permutation test to obtain significance levels
for tests of dimension.  \code{dr.coplot} allows visualizing the results using a
coplot of either two selected directions conditioning on a third and using
color to mark the response, or the resonse versus one direction,
conditioning on a second direction.  \code{plot.dr} provides the default plot
method for dr objects, based on a scatterplot matrix.
}

\value{
dr returns an object that inherits from dr (the name of the type is the
value of the \code{method} argument), with attributes:
  \item{M}{A matrix that depends on the method of computing.  The column space
of M should be close to the central subspace.}
  \item{evalues}{The eigenvalues of M (or squared singular values if M is not
symmetric).}
  \item{evectors}{The eigenvectors of M (or of M'M if M is not square and
symmetric) ordered according to the eigenvalues.}
  \item{numdir}{The maximum number of directions to be found.  The output
value of numdir may be smaller than the input value.}
   \item{ols.coef}{Estimated regression coefficients, excluding the intercept,
for the (weighted) LS fit.}
   \item{ols.fit}{LS fitted values.}
   \item{slice.info}{output from sir.slice, used by sir and save.}
   \item{method}{the dimension reduction method used.}
Other returned values repeat quantities from input.  

\code{dr.weights} returns a vector of weights NA substituted for estimated
zero weights.  
}

\references{ The details of these methods are given by R. D. Cook 
(1998).  Regression Graphics.  New York:  Wiley.  Equivalent 
methods are also available in Arc, R. D. Cook and S. Weisberg 
(1999).  Applied Regression Including Computing and Graphics, New 
York:  Wiley, www.stat.umn.edu/arc. } \author{Sanford Weisberg, 
sandy@stat.umn.edu 

For weights, see
R. D. Cook and C. Nachtsheim (1994), Reweighting to achieve
elliptically contoured predictors in regression.  Journal of the American
Statistical Association, 89, 592--599.} %


\seealso{\code{\link{dr.permutation.test}},\code{\link{dr.x}},\code{\link{dr.y}},
\code{\link{dr.direction}},\code{\link{dr.coplot}},\code{\link{dr.weights}}}

\examples{
library(dr)
data(ais)
attach(ais)  # the Australian athletes data
#fit dimension reduction using sir
m1 <- dr(LBM~Wt+Ht+RCC+WCC, method="sir", nslices = 8)
summary(m1)

# repeat, using save:

m2 <- update(m1,method="save")
summary(m2)

# repeat, using phd:

m3 <- update(m2, method="phdres")
summary(m3)
}

# repeat, using weights:

w1 <- dr.weights(LBM~Wt+Ht+RCC+WCC, method="sir", nslices = 8)
m4 <- dr(LBM~Wt+Ht+RCC+WCC, method="sir", nslices = 8, weights=w1)
\keyword{regression }%-- one or more ...

\eof
\name{dr.coplot}
\alias{dr.coplot}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Visualize dimension reduction regression using a coplot }
\description{
  This function produces a coplot of the response versus specified
  directions in dimension reduction regression.
}
\usage{
dr.coplot(object, which=1:object$numdir, mark.by.y=F, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ a dr object }
  \item{which}{ specify the indices of the directions to be plotted }
  \item{mark.by.y}{ if FALSE, plot the response versus the first specified
  direction conditioning on the second specified direction.  If TRUE, plot
  first direction versus second direction conditioning on the third
  direction, using the response as a marking variable to color the points.}
  \item{\dots}{ other arguments passed to coplot }
}
\details{
The function dr.permutation.test.statistic is not to be called by the user,
but it computes the test statistic for each different type of dr object.
}
\value{
  A coplot.
}
\author{ Sanford Weisberg <sandy@stat.umn.edu> }

\seealso{  \code{\link{dr}} }

\keyword{ regression }% at least one, from doc/KEYWORDS

\eof
\name{dr.directions}
\alias{dr.direction}
\alias{dr.directions}
\alias{dr.direction.default}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Directions selected by dimension reduction regressiosn }
\description{
  Dimension reduction regression returns a set of p orthogonal direction
  vectors each of length p, the first d of which are estimates a basis of a 
  d dimensional central subspace.  The function returns the estimated directions 
  in the original n dimensional space for plotting.}
}
\usage{
dr.direction(object, which, norm, x)
dr.directions(object, which, norm, x)
dr.direction.default(object, which=1:object$numdir,norm=F,x=dr.x(object))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ a dimension reduction regression object }
  \item{which}{ select the directions wanted, default is all directions }
  \item{norm}{if TRUE, direction vectors are normalized to length 1, otherwise
  their length is arbitrary}
  \item{x}{select the X matrix, the default is dr.x(object)}
  \item{...}{additional arguments are passed to dr.direction.default}
}
\details{
  Dimension reduction regression is used to estimate a basis of the central
  subspace of a regression.  If there are p predictors, the dimension
  reduction regression object includes a p by p matrix of C of eigenvectors.
  This method returns (X-m1')C where m is the vector of column means of X.  If
  X is equal to the original matrix of predictors given by dr.x(object), then
  this gives the directions in the coordinates of the orginal n dimensional
  space.  These directions are used in graphical methods and elsewhere.
}
\value{
  Returns a matrix.  The same function has two names.
}
\references{ See R. D. Cook (1998).  Regression Graphics.  New York:  Wiley. }
\author{Sanford Weisberg <sandy@stat.umn.edu> }


\seealso{  \code{\link{dr}} }

\examples{
library(dr)
data(ais)
attach(ais)  # the Australian athletes data
#fit dimension reduction using sir
m1 <- dr(LBM~Wt+Ht+RCC+WCC, method="sir", nslices = 8)
summary(m1)
dr.directions(m1)
}
\keyword{ regression }% __ONLY ONE__ keyword per line

\eof
\name{dr.estimate.weights}
\alias{dr.estimate.weights}
\alias{robust.center.scale}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Compute estimated weighting toward normality}
\description{
  This function estimate weights to apply to the rows of a data matrix to
  make the resulting weighted matrix as close to multivariate normality as
  possible.  This method is usually not called directly by the user.
}
\usage{
dr.estimate.weights(object, sigma=1, covmethod="mve", nsamples=NULL, ...)
robust.center.scale(x, method,... )
}
\arguments{
  \item{object}{a dimension reduction regression object name, or an n by p matrix}
  \item{sigma}{A tuning parameter, with default 1, usually in the range .2
  to 1.0}
  \item{covmethod}{covmethod is passed as the argument \code{method} 
  to the function \code{cov.rob} in the required package
  \code{lqs}.  The choices are \code{"classical"},
  \code{"mve"} and \code{"mcd"}.  This probably will not work with Splus.
  If classical is selected, the usual estimate of the covariance matrix is
  used, but the center is the medians, not the means.}
  \item{nsamples}{The weights are determined by random sampling from a
  data-determined normal distribution.  This controls the number of samples}
  \item{x}{An \eqn{n \times p}{n by p} data matrix with no missing values}
  \item{method}{see covmethod above}
  \item{\dots}{Additional args are passed to \code{cov.rob}}
}
\details{
  The basic outline is:  (1) Estimate a mean m and covariance matrix S using a
  possibly robust method; (2) For each iteration, obtain a random vector
  from N(m,sigma*S).  Add 1 to a counter for observation i if the i-th row
  of the data matrix is closest to the random vector; (3) return as weights
  the sample faction allocated to each observation.  If you set the keyword
  \code{weights.only} to \code{T} on the call to \code{dr}, then only the
  list of weights will be returned.}
}
\value{
  Returns a list of n weights, some of which may be zero.  
}
\references{ R. D. Cook and C. Nachtsheim (1994), Reweighting to achieve
elliptically contoured predictors in regression.  Journal of the American
Statistical Association, 89, 592--599.}
\author{Sanford Weisberg, sandy@stat.umn.edu}

\seealso{\code{\link{dr.weights}}, \code{\link{lqs}} }

%\examples{
%}
\keyword{ regression}%-- one or more ...

\eof
\name{dr.fit}
\alias{dr.fit}
\alias{dr.fit.y}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Fit dimension reduction regression }
\description{
  Internal function that estimates the central subspace.  This will not
  typically be called directly by the user.  dr.fit.y is the generic name
  of a function that returns the response for the particular dimension
  reduction regression object.  Typically, this just returns a centered
  version of the response, but for phdres it returns OLS residuals.
}
\usage{
dr.fit(object, numdir=4, tol=1e-07, ...)
dr.fit.y(object)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ dimension reduction regression object }
  \item{numdir}{ maximum number of dimensions to consider }
  \item{tol}{ tolerance passed to singular value decomposition }
  \item{\dots}{ other arguments passed to dr.fit.M }
}

\value{
  \item{evectors }{ordered eigenvectors that describe the estimates of the 
  dimension reduction subspace}
  \item{evalues }{ordered eigenvalues}
  \item{numdir}{number of eigenvalues}
  \item{raw.evectors}{eigenvectors of the rotated data}
  \item{decomp}{which decomposition was used?}
}
%\references{ ~put references to the literature/web site here ~ }
\author{Sanford Weisberg <sandy@stat.umn.edu> }

\seealso{  \code{\link{dr}} }
\keyword{regression}

\eof
\name{dr.indep.test.phdres}
\alias{dr.indep.test.phdres}
\alias{cov.ew.matrix}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Test of independence for pHd based on residuals }
\description{
  Compute the p-value for the hypothesis that the central
  subspace for OLS residuals has dimension 0 against the alternative that it
  is greater than zero.  This is an
  internal method not usually needed by the user.
}
\usage{
dr.indep.test.phdres(object, stat)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ phdres object }
  \item{stat}{ value of the test statistic }
}

\references{ R. D. Cook (1998) Regression Graphics, New York:  Wiley. }
\author{ Sanford Weisberg <sandy@stat.umn.edu> }

\seealso{ \code{\link{dr}} }
\keyword{regression}

\eof
\name{dr.permutation.test}
\alias{dr.permutation.test}
\alias{dr.permutation.test.statistic}
\alias{dr.permutation.test.statistic.default}
\alias{dr.permutation.test.statistic.phd}
\alias{dr.permutation.test.statistic.phdres}
\alias{dr.permutation.test.statistic.phdy}
\alias{print.dr.permutation.test}
\alias{summary.dr.permutation.test}

\title{ Dimension Reduction Regression Functions}
\description{
These functions require a dimension reduction regression object as input to
produce output of various types.
}
\usage{
dr.permutation.test(object, npermute=50,numdir=object$numdir,permute.weights=TRUE)

}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{object}{a dimension reduction regression object created by dr}
 \item{npermute}{number of permutations to compute, default is 50}
 \item{numdir}{maximum permitted value of the dimension, with the default from
the object}
 \item{permute.weights}{If TRUE, permute weights as well as data in the
 permutation test.  If FALSE, do not permute the weights.}
}
%\details{
% ~~ If necessary, more details than the __description__  above ~~
%}
\value{
Returns an object of type 'dr.permutation.test' that can be printed or
summarized to give the summary of the test.
}
\references{See www.stat.umn.edu/arc/addons.html, and then select the article
on dimension reduction regression or inverse regression.}
\author{ Sanford Weisberg, sandy@stat.umn.edu}


\seealso{ \code{\link{dr}} }

\examples{
data(ais)
attach(ais)  # the Australian athletes data
#fit dimension reduction regression using sir
m1 <- dr(LBM~Wt+Ht+RCC+WCC, method="sir", nslices = 8)
summary(m1)
dr.permutation.test(m1,npermute=100)
plot(m1)
dr.coplot(m1)
}

\keyword{regression}%-- one or more ...

\eof
\name{dr.persp}
\alias{dr.persp}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Produce a perspective plot of dimension reduction regression objects. }
\description{
  This function uses the sm library to draw a perspective 3D plot of two of
  the directions obtained by dimension reduction regression versus the response.
}
\usage{
dr.persp(object, which=1:2, h=c(0.1, 0.1), ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ a dimension reduction regression object }
  \item{which}{ a vector of two directions to use }
  \item{h}{ bandwidths for smoothing passed to sm }
  \item{\dots}{ graphical parameters passed to sm }
}

\value{
  Returns a perspective plot
}
\author{ Sanford Weisberg <sandy@stat.umn.edu>}


\seealso{ \code{\link{dr}}, \code{\link[sm]{sm}} }
\keyword{regression}

\eof
\name{dr.slices}
\alias{dr.slices}
\alias{dr.slice1}
\alias{dr.slice2}
\alias{dr.slice.1d}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Divide a vector into slices of approximately equal size }
\description{
  Divides a vector into slices of approximately equal size.
}
\usage{
dr.slices(y, nslices)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{y}{a vector of length n or an n by p matrix}
  \item{nslices}{the number of slices, no larger than n, or a vector of
  p numbers giving the number of slices in each direction.  If y has p 
  columns and nslices is a number, then the number of slices in each direction
  is the smallest integer greater than the p-th root of nslices.}
}
\details{
  If y is an n-vector, order y.  The goal for the number of observations per slice
  is m, the smallest integer in nslices/n. Allocate the first m observations to
  slice 1.  If there are duplicates in y, keep adding observations to the first
  slice until the next value of y is not equal to the largest value in the 
  first slice.  Allocate the next m values to the next slice, and again check 
  for ties.  Continue until all values are allocated to a slice.  This does not
  guarantee that nslices will be obtained, nor does it guarantee an equal number
  of observations per slice.  This method of choosing slices is invariant under
  rescaling, but not under multiplication by -1, so the slices of y will not
  be the same as the slices of -y.
  
  If y is a matrix of p columns, slice the first column as described above.  Then,
  within each of the slices determined for the first column, slice based on the
  second column, so that each of the "cells" has approximately the same number
  of observations.  Continue through all the columns.  This method is not
  invariant under reordering of the columns, or under multiplication by -1.
}
\value{
  \item{slice.sizes} {gives the number
  of observations per slice.  }
  \item{slice.indicator} {is an n-vector giving the
  slice number of each observation.  }
  \item{nslices} {gives the actual number of slices produced}
}
\references{ This function produces the same slice indicators as does the
equivalent function in Arc, Cook and Weisberg (1999), Applied Regression Including
Computing and Graphics, New York:  Wiley. }
\author{ Sanford Weisberg, <sandy@stat.umn.edu> }

\seealso{  \code{\link{dr}} }

\keyword{ regression }% __ONLY ONE__ keyword per line

\eof
\name{dr.test}
\alias{dr.test}
\alias{dr.test.default}
\alias{dr.test.phd}
\alias{dr.test.phdq}                        
\alias{dr.test.phdres}                       
\alias{dr.test.phdy}                         
\alias{dr.test.sir}                          
\alias{dr.test2.phdres}    
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Dimension reduction regression tests }
\description{
  This method computes tests of dimension in dimension reduction regression.
  A separate method is needed for each dimension reduction regression method.
  Called by the dr function, and not usually accessed directly by the user.
}
\usage{
dr.test(object, nd) 
dr.test.default(object, nd)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{ dimension reduction regresion object }
  \item{nd}{ Maximum number of dimensions to test }
}

\value{
 Returns test statistics and significance levels in a data frame.
}
\references{ R. C. Cook (1998).  Regression Graphics. New York:  Wiley. }
\author{Sanford Weisberg, <sandy@stat.umn.edu> }


\seealso{ \code{\link{dr}} }
\keyword{regression}

\eof
\name{dr.x}
\alias{dr.x}
\alias{dr.y}
\alias{dr.z}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Inverse regression term matrix}
\description{
dr.x returns the matrix of data constructed from the formula for a
dimension reduction regression.  dr.y returns the response.
}
\usage{
dr.x(object)
dr.y(object)
dr.z(x,weights=NULL,center=TRUE,rotate=TRUE,decomp="svd")
}
\arguments{
 \item{object}{An dimension reduction regression object}
 \item{x}{a matrix to be centered and scaled OR a dimension reduction object
 from which the model matrix will be extracted}
 \item{weights}{a vector of weights, or NULL if unweighted}
 \item{center}{if TRUE, center the output}
 \item{rotate}{if TRUE, multiply by the inverse square root of the sample
 covariance matrix.}
 \item{decomp}{Decomposition to be used in computing the rotation; the
 default is "svd".}
}
\value{
dr.x returns an \eqn{n \times p}{n by p} matrix of terms, excluding the 
intercept, constructed from the dimension reduction regression object.  dr.y returns the
response. dr.z returns a possibly centered and scaled version of x.
}
\author{Sanford Weisberg, <sandy@stat.umn.edu>}

\seealso{dr}

\examples{
data(ais)
attach(ais)
m1 <- dr(LBM~Ht+Wt+RCC+WCC)
dr.x(m1)
dr.y(m1)
}
\keyword{regression}%-- one or more ...

\eof
\name{fullquad.fit}
\alias{fullquad.fit}
\alias{fullquad.residuals}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Fit a full second-order model}
\description{
  This function fits an ordinary LS regression of a response on a full
  second order model, or returns the residuals from such a fit. Used in the
  phdq method in dr.
}
\usage{
fullquad.fit(x, y, w, ...)
fullquad.residuals(...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{ an n by p matrix of predictors}
  \item{y}{ an n vector of the response}
  \item{w}{ an n vector of positive weights or NULL}
  \item{\dots}{ arguments passed to lm}
}
\value{
  fullquad.fit returns an object of type lm.  fullquad.residuals returns a
  vector of n residuals.
}
\author{ Sanford Weisberg <sandy@stat.umn.edu>}



\keyword{ regression }% at least one, from doc/KEYWORDS

\eof
\name{givens.rotation}
\alias{givens.rotation}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Create givens rotation matrix}
\description{
For a given angle theta, returns a p by p Givens rotation matrix.
}
\usage{
givens.rotation(theta, p=2, which=c(1, 2))
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{theta}{an angle in radians}
 \item{p}{the dimension of the matrix to be produced}
 \item{which}{two numbers between 1 and p giving the columns/rows for the
nonzero elements of the result.}
}
\value{
Returns a p by p matrix z of all zeroes, except z[which,which] has elements
cos(theta), -sin(theta), sin(theta) and cos(theta), in column order.
}
\references{
Gene H. Golub and Charles F. Van Loan (1989).  Matrix Computations, Second
Edition.  Baltimore:  Johns Hopkins Press, p. 202.}
\author{sandy@stat.umn.edu}

\examples{
 givens.rotation(1,4,c(1,3))
}
\keyword{ regression }%-- one or more ...

\eof
\name{markby}
\alias{markby}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Produce a vector of colors/symbols to mark points}
\description{
This function creates marking of points by color or symbol for use in graphs.
}
\usage{
markby(z, use="color", values=NULL, color.fn=rainbox, na.action="na.use")
}
\arguments{
 \item{z}{a variable with a few distict values that will define the groups for
marking.}
 \item{use}{if equal to \code{"color"}, will returna list of colors.  If
anything else, it will return a list of symbols for marking.}
 \item{values}{a list with as many values as unique values of z that determine
the colors or symbols.  If this is not set, then the function rainbow is used
for colors and 1:length(unique(z)) is used for symbols.}
 \item{color.fn} {This is the name of a function that when called with a
 single argument of length k returns a list of k acceptable color names.
 The function rainbow is a standard function in \R; see the help for this
 function for other choices.}
 \item{na.action}{By default, missing values (NAs) are treated as another
 category in the color marking.  Setting this argument to anything else will
 return NA for the missing category names.  This will cause an error in \R\
 graphics routines, but see below for usage of this options.}
}
\value{
Returns length(z) values that specify the color or symbol for each point.
}
\references{This function is to help users familiar with Arc, as discussed in
R. D. Cook and S. Weisberg (1999).  \emph{Applied Regression Including
Computing and Graphics}, New York:  Wiley.}
\author{Sanford Weisberg, <sandy@stat.umn.edu>}


\examples{
  x <- rnorm(100)
  y <- rnorm(100)
  z <- cut(rnorm(100),3)
# Scatterplot, mark using color with groups determined by Status
  plot(x,y,col=markby(z))
# Scatterplot, mark using symbols with groups determined by Status
  plot(x,y,pch=markby(z,use="symbols"))
# handing of missing values:
  z[1:10] <- NA   # set to missing
  marks <- markby(z,na.action="omit")
  sel <- !is.na(marks)
  plot(x[sel],y[sel],col=marks[sel])
}
\keyword{ regression }%-- one or more ...

\eof
\name{mussels}
\alias{mussels}
\title{Mussels' muscles data}
\non_function{}
\description{
Data were furnished by Mike Camden, Wellington Polytechnic, Wellington,
New Zealand.  Horse mussels, (Atrinia), were sampled from the Marlborough
Sounds.  The response is the mussels' Muscle Mass.
}
\format{This data frame contains the following columns:
 \describe{
    \item{H}{
 Shell height in mm
    }
    \item{L}{
 Shell length in mm
    }
    \item{M}{
 Muscle mass in g
    }
    \item{S}{
 Shell mass in g
    }
    \item{W}{
 Shell width in mm
    }
 }
}
\details{}
\source{R. D. Cook and S. Weisberg (1999). \emph{Applied
Statistics Including Computing and Graphics}.  New York:  Wiley.}
\keyword{datasets}

\eof
\name{rotplot}
\alias{rotplot}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{draw many 2D projections of a 3D plot}
\description{
This function draws several 2D views of a 3D plot, sort of like a spinning
plot.
}
\usage{
rotplot(x, y, number=9, theta=seq(0, pi/2, length = 9), ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
 \item{x}{a matrix with 2 columns giving the horizontal axes of the full 3D
plot.}
 \item{y}{the vertical axis of the 3D plot.}
 \item{number}{Number of 2D views of the 3D plot.}
 \item{theta}{a list of rotation angles}
 \item{\dots}{additional arguments passed to coplot}
}
\details{
For each value of theta, draw the plot of cos(theta)*x[,1]+sin(theta)*x[,2]
versus y.
}
\value{
returns a graph object.
}
%\references{ ~put references to the literature/web site here ~ }
\author{Sanford Weisberg, sandy@stat.umn.edu}
%\note{ ~~further notes~~ }
%
% ~Make other sections like WARNING with \section{WARNING }{....} ~
%
%\seealso{ ~~objects to SEE ALSO as \code{\link{~~fun~~}}, ~~~ }
%
\examples{
 data(ais)
 attach(ais)
 m1 <- dr(LBM ~ Ht + Wt + WCC)  % Estimate central subspace via SIR
 rotplot(dr.direction(m1,which=1:2),dr.y(m1),col=markby(Sex))
  }
\keyword{regression}%-- one or more ...

\eof
\name{wood.pvalue}
\alias{wood.pvalue}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Chi-square approximation to a sum of Chi-squares}
\description{
Returns an approximation to P(coef'X > f) for X=(X1,...,Xk)', a vector of iid
one df chi-squared rvs.  coef is a list of positive coefficients. tol is used
to check for near-zero conditions.
}
\usage{
wood.pvalue(coef, f, tol=0, print=F)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{coef}{ Vector of positive numbers, usually from the eigenvalues of a
  random matrix}
  \item{f}{ observed value of statistic}
  \item{tol}{  A small number for tolerance}
  \item{print}{ If TRUE, print the output; if FALSE return the pvalue}
}
\details{
  Following Wood (1989), use either a Saterthwaite-Welsh, inverse gamma or
  three-parameter Pearson Type IV approximation, depending on the values of
  the coefficients.
}
\value{
  Returns the tail area probability.
}
\references{
See Wood (1989), Communications in Statistics, Simulation 1439-1456.
Translated from Arc function wood-pvalue.
}

\author{ Sanford Weisberg <sandy@stat.umn.edu>.  Arc version by Dennis
Cook.}

\seealso{ \code{\link{dr}} }

\keyword{ regression }% __ONLY ONE__ keyword per line

\eof
